:hide-toc:

******
pep621
******

PEP 621 metadata parsing.


API Reference
=============


.. autoclass:: pep621.StandardMetadata
   :members:
   :undoc-members:

.. autoclass:: pep621.ConfigurationError
   :members:
   :undoc-members:

.. autoclass:: pep621.License
   :members:
   :undoc-members:

.. autoclass:: pep621.Readme
   :members:
   :undoc-members:

.. autoclass:: pep621.RFC822Message
   :members:
   :undoc-members:

.. autoclass:: pep621.DataFetcher
   :members:
   :undoc-members:


.. toctree::
   :hidden:

   changelog

.. toctree::
   :caption: Project Links
   :hidden:

   Source Code <https://github.com/FFY00/python-pep621>
   Issue Tracker <https://github.com/FFY00/python-pep621/issues>
